===================================================
:mod:`numina.instrument` --- Instrument description
===================================================

.. automodule:: numina.instrument.assembly
   :members:

.. automodule:: numina.instrument.configorigin
   :members:

.. automodule:: numina.instrument.device
   :members:

.. automodule:: numina.instrument.generic
   :members:

.. automodule:: numina.instrument.hwdevice
   :members: